<?php

// No direct access allowed
if (!defined('ABSPATH')) exit;

class ClarifyIP
{
    public function __construct()
    {
        //Add settings link
        add_filter('plugin_action_links_' . CLARIFYIP_PLUGIN_BASE_FILE, array('ClarifyIP', 'settings_link'));

        // Frontend init plugin
        add_action('init', array('ClarifyIP_Api', 'init'));

        // Admin init plugin
        add_action('admin_init', array('ClarifyIP_Admin', 'init'));
        add_action('admin_menu', array('ClarifyIP_Admin', 'add_admin_page'));

        // Admin Api key check
        add_action('admin_notices', array('ClarifyIP', 'clarifyip_plugin_api_check'));

        // Plugin uninstall hook
        register_uninstall_hook(CLARIFYIP_PLUGIN_BASE_FILE, array('ClarifyIP', 'uninstall'));
    }

    // Api key check
    public static function clarifyip_plugin_api_check()
    {
        // Restrict showing only on 'clarifyip' plugin page
        // if (!empty($_SERVER['QUERY_STRING']) && $_SERVER['QUERY_STRING'] == 'page=clarifyip') {
        $options = get_option('clarifyip_plugin_options');
        $error_message = 'There has been an error with your ClarifyIP API key.';
        $error_message_link = '<br>Please visit this <a href="' . admin_url("options-general.php?page=clarifyip") . '">link</a> to check your ClarifyIP API key.';

        if (!empty($options['api_key'])) {
            $response = WpOrg\Requests\Requests::get(
                'https://api.clarifyip.com/status/?key=' . esc_html(sanitize_text_field($options['api_key'])),
                array('Referer' => get_bloginfo('wpurl'))
            );
            // Check if response code is 200
            if ($response->status_code == 200) {
                $response = json_decode($response->body, true);

                // Universal error
                if (isset($response['error'])) {
                    echo '<div class="notice notice-error"><p>' . wp_kses_post($error_message) . '</p></div>';
                }
                // Quota limit error or bad api key
                elseif (isset($response['status']) && $response['status'] == 'e') {
                    echo '<div class="notice notice-error"><p>ClarifyIP plugin: ' . (wp_kses_post($response['msg']) ?? $error_message) . wp_kses_post($error_message_link) . '</div>';
                }
                // Success. Display quota to user
                elseif (isset($response['status']) && $response['status'] == 's') {
                    echo '<script>
                            jQuery(document).ready(function() {
                                jQuery("#clarifyip_plugin_setting_quota").html("Quota:  ' . wp_kses_post($response['req']) . ' / ' . wp_kses_post($response['limit']) . ' used");
                            });
                        </script>';
                }
            } else {
                echo '<div class="notice notice-error"><p>' . wp_kses_post($error_message) . '</p></div>';
            }
        } else {
            echo '<div class="notice notice-warning"><p>API key is missing.' . wp_kses_post($error_message_link) . '</p></div>';
        }
        // }
    }

    // Settings link on plugin listing page
    public static function settings_link($links)
    {
        $settings_link = '<a href="/wp-admin/options-general.php?page=clarifyip">Settings</a>';
        array_unshift($links, $settings_link);
        return $links;
    }

    // Unistall plugin
    public static function uninstall()
    {
        // Delete ClarifyIP options from database
        delete_option('clarifyip_plugin_options');
    }
}
